# Time Slicer

A Python package for creating timeslice images from time lapses.

Contains a module for importing the time slice function into other Python projects and a main 
script for creating a timeslice from the terminal.

## Usage

```commandline
pip install timeslicer==1.1.1
```

Create Timeslice from terminal:
```commandline
python3 -m timeslicer
```

You will then be prompted by the terminal to enter information necessary to create tome slice.

## Sample Output Images

### Standard Timeslice

![standard](https://raw.githubusercontent.com/nramkissoon/Time-Slicer/master/samples/test.jpg)

### Randomized Timeslice

![randomized](https://raw.githubusercontent.com/nramkissoon/Time-Slicer/master/samples/test-randomized.jpg)